# Deal with odd and inconsistent upstream naming:
%define myname minisat
%define myversion 070721

Summary: A minimalistic, open-source SAT solver
Name: minisat2
Version: 2.0
# Use Fedora 'Snapshot' naming convention due to odd upstream version naming:
Release: 7.20070721%{?dist}
License: MIT
Group: Applications/Engineering
Source: http://minisat.se/downloads/%{name}-%{myversion}.zip
# Sent sources, test, patches (below) to upstream via email on 2008-07-08:
Source1: http://www.dwheeler.com/essays/minisat-user-guide-1.0.html
Source2: minisat2-test.in
Patch1: minisat2-FPU.patch
Patch2: minisat2-template.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
URL: http://minisat.se/
BuildRequires: zlib-devel

%description
MiniSat is a minimalistic, open-source Boolean satisfiability problem
(SAT) solver, developed for researchers and developers alike.
Winning all the industrial categories of the SAT 2005 competition,
MiniSat is a good starting point both for future research in SAT, and
for applications using SAT.

A SAT solver can determine if it is possible to find assignments to boolean
variables that would make a given expression true, if the expression is
written with only AND, OR, NOT, parentheses, and boolean variables.
If the expression is satisfiable, MiniSAT can also produce a
set of assignments that make the expression true.
Although the problem is NP-complete, SAT solvers (like this one)
are often able to decide this problem in a reasonable time frame.

%prep
%setup -q -n %{myname}
%patch1 -p1 
%patch2 -p1 

%build
cp -p %{SOURCE1} .
cp -p %{SOURCE2} .
mv minisat-user-guide-*.html minisat-user-guide.html

# Show key execution steps, so we can see that the right flags are used.
sed -i 's/@$(CXX)/$(CXX)/' mtl/template.mk 

# Note: Could get a 1-2% speed boost by building as static (use "rs" instead
# of "r" when invoking "make"), but static executables are dispreferred by
# Fedora (they create update complications and are larger).
# If static executables were added later, they would need to
# add a dependency on zlib-static.

# Build "simp", which adds simplification capabilities, instead of just "core"
pushd simp
 make CFLAGS="-I../mtl -I../core -Wall -ffloat-store %{optflags}" r
 cp -p %{myname}* ../%{myname}
popd

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_bindir}
install -m 0755 %{myname} %{buildroot}%{_bindir}/

%check
# Test "minisat2-test.in" is a brief quote from
# http://www.satcompetition.org/2004/format-solvers2004.html
./minisat minisat2-test.in minisat2-test.out
echo
echo "RESULTS:"
cat minisat2-test.out
result=`head -1 minisat2-test.out`
if [ "$result" = "SAT" ]; then
  echo "SUCCESS - Correctly found that it was satisfiable"
  true
else
  echo "Failed test."
  false
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc LICENSE
%doc minisat-user-guide.html
%doc minisat2-test.in
%doc minisat2-test.out
%attr(755,root,root) %{_bindir}/%{myname}


%changelog
* Tue Aug 7 2008 David A. Wheeler <dwheeler at, dwheeler.com> 2.0-7.20070721
- Removed code for switching between -O2 and -O3, per reviewer request.

* Tue Aug 7 2008 David A. Wheeler <dwheeler at, dwheeler.com> 2.0-6.20070721
- Timing tests found -O3 was unhelpful; switched back to -O2, but left stub
  in case a switch to another -O level would help in the future.
  -O3 real 0m35.714s, 0m35.714s, 0m35.834s vs. -O2 real 0m35.296s, 0m35.301s

* Tue Jul 8 2008 David A. Wheeler <dwheeler at, dwheeler.com> 2.0-5.20070721
- Moved to higher optimization level (-O3); speed is critical for this app.

* Tue Jul 8 2008 David A. Wheeler <dwheeler at, dwheeler.com> 2.0-4.20070721
- Different version number convention to better conform to Fedora guidelines
- Made macro use consistent (not used for simple commands)
- Documented when patches and documentation sent upstream

* Sat Jun 28 2008 David A. Wheeler <dwheeler at, dwheeler.com> 2.0-3.20070721
- Use "make r" instead of "make" to create "released" version
- Wrote brief user guide, included as part of this package.

* Fri Jun 27 2008 David A. Wheeler <dwheeler at, dwheeler.com> 2.0-2.20070721
- Switched from minimal "core" to more-capable "simp" (simplifier)
- Change "make" invocation so CFLAGS includes %%{optflags}
- Add test file and %%check section (so we'd know if it worked!)
- Modified description for people who don't know what SAT solvers are.

* Thu Jun 26 2008 Earl Sammons <esammons at, hush.com> 2.0-1.20070721
- Initial build
- Include Debian patches minisat2-FPU.patch and minisat2-template.patch

